@@ -1,4 +1,4 @@
-from aws_cdk import Stack 
+from aws_cdk import Stack, aws_ssm
 from constructs import Construct
 
 from cdk_toolkit import connection, container
@@ -14,11 +14,15 @@ class VPCStack(Stack):
         ## 
         ## VPC 
         ################################
-        stack_env_name = self.node.try_get_context("env")
+        stack_env_name = "cdktoolkit" #self.node.try_get_context("env")
         self.vpc = connection.createVPC(self, vpc_name, cidr_str, stack_env_name)
 
         priv_subnets = [subnet.subnet_id for subnet in self.vpc.private_subnets]
         count = 1
         for ps in priv_subnets: 
-            container.createSSMStringParameter(self, 'private-subnet-'+ str(count), ps, '/'+stack_env_name+'/private-subnet-'+str(count)) 
-            count += 1  
\ No newline at end of file
+            aws_ssm.StringParameter(self, 'private-subnet-'+ str(count),
+                string_value = ps,
+                parameter_name = '/'+stack_env_name+'/private-subnet-'+str(count)
+                )
+            count += 1  
+         
\ No newline at end of file
